import numpy as np
import pandas as pd
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from matplotlib import rcParams

rcParams["text.usetex"] = True
rcParams["font.serif"] = "Times New Roman"
rcParams["font.family"] = "Serif"
rcParams["xtick.labelsize"]=28
rcParams["ytick.labelsize"]=28
rcParams["legend.fontsize"]=26
rcParams["axes.labelsize"]=28

bpl_df = pd.read_csv('O1O2O3a_bpl_pval.csv', sep=' ')
plp_df = pd.read_csv('O1O2O3a_plp_pval.csv', sep=' ')
x_min = 0.9
x_max = 25.0


fig = plt.figure(figsize=(12,7))
ax = fig.add_subplot(111)
ax.plot(bpl_df.index.values + 1, bpl_df['pval'], linestyle='-', marker='o', color='darkorchid', label='\\textsc{Broken power-law}', markersize=8, linewidth=2)
ax.plot(plp_df.index.values + 1, plp_df['pval'], linestyle='-', marker='o', color='steelblue', label='\\textsc{Power-law peak}', markersize=8, linewidth=2)

for i, txt in enumerate(bpl_df['ID']):
    if(i < 4):
        ax.annotate(txt, (bpl_df.index.values[i] + 1, 0.0012), rotation=90, color='black', size=24)

plt.hlines(0.5,x_min,x_max,linestyles='solid',linewidths=1,colors='black')
plt.hlines(0.10, x_min,x_max,linestyles='solid',linewidths=1, colors='black')
plt.hlines(0.01, x_min,x_max,linestyles='solid',linewidths=1,colors='black')
plt.loglog()
plt.xticks(bpl_df.index.values + 1)
ax.set_xticks([1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22])
ax.set_xticklabels([1,'','','','','','','','',10,'','','','','','','','','','','',''])
plt.xlim(x_min, x_max)
plt.ylim(1e-3,1)
plt.ylabel('p-value')
plt.xlabel('rank $n$')
plt.grid(which='both',axis='x')
plt.grid(which='both',axis='y')
plt.legend(loc='lower right')
plt.tight_layout()
plt.savefig('./pval_plot_rnp.png')
plt.savefig('./pval_plot_rnp.pdf')
plt.close()
